@@ -361,6 +361,36 @@ internet_address_list_concat (InternetAddressList *a, InternetAddressList *b)
 }
 
 
+/**
+ * internet_address_list_next:
+ * @list: list of internet addresses
+ *
+ * Returns the following node in @list.
+ **/
+InternetAddressList *
+internet_address_list_next (const InternetAddressList *list)
+{
+	if (!list)
+		return NULL;
+
+	return list->next;
+}
+
+/**
+ * internet_address_list_get_address:
+ * @list: list of internet addresses
+ *
+ * Returns the #InternetAddress currently pointed to in @list.
+ **/
+InternetAddress *
+internet_address_list_get_address (const InternetAddressList *list)
+{
+	if (!list)
+		return NULL;
+
+	return list->address;
+}
+
 /**
  * internet_address_list_length:
  * @list: list of internet addresses
@@ -455,12 +485,10 @@ internet_address_list_to_string_internal (const InternetAddressList *list, gbool
 char *
 internet_address_to_string (const InternetAddress *ia, gboolean encode)
 {
-	char *str = NULL;
+	char *name, *str = NULL;
 	
 	if (ia->type == INTERNET_ADDRESS_NAME) {
 		if (ia->name && *ia->name) {
-			char *name;
-			
 			name = encoded_name (ia->name, encode);
 			str = g_strdup_printf ("%s <%s>", name, ia->value.addr);
 			g_free (name);
@@ -471,8 +499,10 @@ internet_address_to_string (const InternetAddress *ia, gboolean encode)
 		InternetAddressList *members;
 		GString *string;
 		
-		string = g_string_new (ia->name);
+		name = encoded_name (ia->name, encode);
+		string = g_string_new (name);
 		g_string_append (string, ": ");
+		g_free (name);
 		
 		members = ia->value.members;
 		internet_address_list_to_string_internal (members, encode, string);
